package org.apache.maven;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;

/**
 * MissingModuleException
 */
public class MissingModuleException
    extends MavenExecutionException
{

    private File moduleFile;
    private final String moduleName;

    public MissingModuleException( String moduleName, File moduleFile, File pomFile )
    {
        super( "The module: " + moduleName + " cannot be found in file: " + moduleFile, pomFile );
        this.moduleName = moduleName;
        this.moduleFile = moduleFile;
    }

    public File getModuleFile()
    {
        return moduleFile;
    }

    public String getModuleName()
    {
        return moduleName;
    }

}
